@@ -1,8 +1,8 @@
-# Copyright (c) 2012 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Client.pm,v 1.17 2011/01/23 12:23:16 gavin Exp $
+# $Id: Client.pm,v 1.17 2008/01/23 12:23:16 gavin Exp $
 package Net::EPP::Client;
 use bytes;
 use Net::EPP::Protocol;
@@ -10,6 +10,7 @@ use Carp;
 use IO::Socket;
 use IO::Socket::SSL;
 use vars qw($XMLDOM $EPPFRAME);
+use UNIVERSAL qw(isa);
 use strict;
 use warnings;
 
@@ -144,6 +145,7 @@ sub new {
 			croak("Frames requested but Net::EPP::Frame isn't available");
 
 		} else {
+			$self->{'parser'} = XML::LibXML->new;
 			$self->{'class'} = 'Net::EPP::Frame';
 
 		}
@@ -153,10 +155,15 @@ sub new {
 			croak("DOM requested but XML::LibXML isn't available");
 
 		} else {
+			$self->{'parser'} = XML::LibXML->new;
 			$self->{'class'} = 'XML::LibXML::Document';
 
 		}
 
+	} else {
+		# for well-formedness checking:
+		$self->{'parser'} = XML::LibXML->new;
+
 	}
 
 	return bless($self, $package);
@@ -178,11 +185,9 @@ certificate information). See the relevant manpage for examples.
 This method will C<croak()> if connection fails, so be sure to use C<eval()> if
 you want to catch the error.
 
-By default, the return value for C<connect()> will be the EPP E<lt>greetingE<gt>
-frame returned by the server. Please note that the same caveat about blocking
-applies to this method as to C<get_frame()> (see below).
-
-If you want to get the greeting yourself, set C<$params{no_greeting}>.
+The return value for C<connect()> will be the EPP C<E<lt>greetingE<gt>> frame
+returned by the server. Please note that the same caveat about blocking applies
+to this method as to C<get_frame()> (see below).
 
 =cut
 
@@ -197,7 +202,7 @@ sub connect {
 
 	}
 
-	return ($params{'no_greeting'} ? 1 : $self->get_frame);
+	return $self->get_frame;
 
 }
 
@@ -232,7 +237,7 @@ sub _connect_unix {
 		%params
 	);
 
-	croak("Connection to $self->{'host'}:$self->{'port'} failed: $@") if (!defined($self->{'connection'}) || ($@ && $@ ne ''));
+	croak("Connection to $self->{'host'}:$self->{'port'} failed: \"$@\"") if (!defined($self->{'connection'}) || ($@ && $@ ne ''));
 
 	return 1;
 
@@ -303,7 +308,7 @@ sub get_return_value {
 
 	} else {
 		my $document;
-		eval { $document = $self->parser->parse_string($xml) };
+		eval { $document = $self->{'parser'}->parse_string($xml) };
 		if (!defined($document) || $@ ne '') {
 			chomp($@);
 			croak(sprintf("Frame from server wasn't well formed: %s\n\nThe XML looks like this:\n\n%s\n\n", $@, $xml));
@@ -368,7 +373,7 @@ sub send_frame {
 	}
 
 	if ($wfcheck == 1) {
-		eval { $self->parser->parse_string($xml) };
+		eval { $self->{'parser'}->parse_string($xml) };
 		if ($@ ne '') {
 			chomp($@);
 			croak(sprintf("Frame from server wasn't well formed: %s\n\nThe XML looks like this:\n\n%s\n\n", $@, $xml));
@@ -385,7 +390,7 @@ sub send_frame {
 	$epp->disconnect;
 
 This closes the connection. An EPP server should always close a connection after
-a E<lt>logoutE<gt> frame has been received and acknowledged; this method
+a C<E<lt>logoutE<gt>> frame has been received and acknowledged; this method
 is provided to allow you to clean up on the client side, or close the
 connection out of sync with the server.
 
@@ -405,7 +410,7 @@ CentralNic Ltd (L<http://www.centralnic.com/>).
 
 =head1 COPYRIGHT
 
-This module is (c) 2012 CentralNic Ltd. This module is free software; you can
+This module is (c) 2006 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
@@ -424,10 +429,4 @@ redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
-sub parser {
-	my $self = shift;
-	$self->{'parser'} = XML::LibXML->new if (!$self->{'parser'});
-	return $self->{'parser'};
-}
-
 1;
