@@ -1,4 +1,4 @@
-# Copyright (c) 2009 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
@@ -95,6 +95,34 @@ C<$Net::EPP::Simple::Error> and C<$Net::EPP::Simple::Code>.
 sub new {
 	my ($package, %params) = @_;
 	$params{dom}		= 1;
+
+	eval 'use Config::Simple';
+	if (!$@) {
+		# we have Config::Simple, so let's try to parse the RC file:
+		my $rcfile = $ENV{'HOME'}.'/.net-epp-simple-rc';
+		if (-e $rcfile) {
+			my $config = Config::Simple->new($rcfile);
+
+			# if no host was defined in the constructor, use the default (if specified):
+			if (!defined($params{'host'}) && $config->param('default.default')) {
+				$params{'host'} = $config->param('default.default');
+			}
+
+			# if no debug level was defined in the constructor, use the default (if specified):
+			if (!defined($params{'debug'}) && $config->param('default.debug')) {
+				$params{'debug'} = $config->param('default.debug');
+			}
+
+			# grep through the file's values for settings for the selected host:
+			my %vars = $config->vars;
+			foreach my $key (grep { /^$params{'host'}\./ } keys(%vars)) {
+				my $value = $vars{$key};
+				$key =~ s/^$params{'host'}\.//;
+				$params{$key} = $value unless (defined($params{$key}));
+			}
+		}
+	}
+
 	$params{port}		= (defined($params{port}) && int($params{port}) > 0 ? $params{port} : 700);
 	$params{ssl}		= ($params{no_ssl} ? undef : 1);
 
@@ -107,14 +135,22 @@ sub new {
 	$self->{reconnect}	= (defined($params{reconnect}) ? int($params{reconnect}) : 3);
 	$self->{connected}	= undef;
 	$self->{authenticated}	= undef;
+	$self->{connect}	= (exists($params{connect}) ? $params{connect} : 1);
+	$self->{login}		= (exists($params{login}) ? $params{login} : 1);
 
 	bless($self, $package);
 
-	return ($self->_connect ? $self : undef);
+	if ($self->{connect}) {
+		return ($self->_connect($self->{login}) ? $self : undef);
+
+	} else {
+		return $self;
+
+	}
 }
 
 sub _connect {
-	my $self = shift;
+	my ($self, $login) = @_;
 
 	$self->debug(sprintf('Attempting to connect to %s:%d', $self->{host}, $self->{port}));
 	eval {
@@ -133,8 +169,21 @@ sub _connect {
 
 	map { $self->debug('S: '.$_) } split(/\n/, $self->{greeting}->toString(1));
 
-	$self->debug('Connected OK, preparing login frame');
+	$self->debug('Connected OK');
 
+	if ($login) {
+		return $self->_login;
+
+	} else {
+		return 1;
+
+	}
+}
+
+sub _login {
+	my $self = shift;
+
+	$self->debug('preparing login frame');
 	my $login = Net::EPP::Frame::Command::Login->new;
 
 	$login->clID->appendText($self->{user});
